@@ -46,60 +46,62 @@ Create.actor.reddit <- function(datasource, type, weightEdges = FALSE, textData
 
   # append string to file name to indicate different graph types, only used if writeToFile = TRUE
   append_type <- ""
-  thread_df <- datasource
+  df_thread <- datasource
 
-  # actor_network <- RedditExtractoR::user_network(thread_df, include_author = TRUE, agg = FALSE)
+  # actor_network <- RedditExtractoR::user_network(df_thread, include_author = TRUE, agg = FALSE)
 
   # modified from RedditExtractoR::user_network to include the df comment id, subreddit and thread id as edge 
-  # attributes to support post-processing. author of sender_receiver_df, node_df, and edge_df @ivan-rivera.
+  # attributes to support post-processing. df_relations, df_nodes, and df_edges based on network by @ivan-rivera.
   include_author <- TRUE
 
   # select cols and rename id and user
-  sender_receiver_df <- thread_df %>% 
+  df_relations <- df_thread %>% 
     dplyr::select(.data$id, .data$subreddit, .data$thread_id, .data$structure, .data$user, .data$author, 
                   .data$comment) %>% 
     dplyr::rename("comment_id" = .data$id, "sender" = .data$user)
 
-  sender_receiver_df %<>%
+  df_relations %<>%
     # response_to = "" if structure doesnt contain an underscore
     # else set to structure minus last digit '1_1_2' response_to = '1_1' 
     dplyr::mutate(response_to = ifelse(!grepl("_", .data$structure), "", gsub("_\\d+$", "", .data$structure))) %>%
     
     # select structure and user from original df
     # rename structure to response_to and user to receiver
-    # left join sender_receiver_df to response_to, receiver by response_to
+    # left join df_relations to response_to, receiver by response_to
     # FIXED: crossing threads by joining only on structure (response_to)
-    dplyr::left_join(thread_df %>% 
+    dplyr::left_join(df_thread %>% 
                      dplyr::select(.data$thread_id, .data$structure, .data$user) %>%
                      dplyr::rename("response_to" = .data$structure, "receiver" = .data$user),
                      by = c("response_to" = "response_to", "thread_id" = "thread_id"))
 
   # above seems correct ^
   
-  sender_receiver_df %<>%
+  df_relations %<>%
     # inserts author into missing receiver values
     # FIXED: coalesce was crossing threads
     # dplyr::mutate(receiver = dplyr::coalesce(.data$receiver, ifelse(include_author, .data$author, ""))) %>%
     dplyr::mutate(receiver = ifelse(is.na(.data$receiver), .data$author, .data$receiver)) %>%
   
     # filter out when sender and receiver same, or if either deleted or empty string
-    dplyr::filter(.data$sender != .data$receiver, 
-                  !(.data$sender %in% c("[deleted]", "")), 
-                  !(.data$receiver %in% c("[deleted]", ""))) %>% 
+    # dplyr::filter(.data$sender != .data$receiver, 
+    #               !(.data$sender %in% c("[deleted]", "")), 
+    #               !(.data$receiver %in% c("[deleted]", ""))) %>%
+    # have to decide on deleted, self loops are fine
+    # removed comments have the value "[removed]"
     dplyr::mutate(count = 1) %>%
     dplyr::select(.data$sender, .data$receiver, .data$comment_id, .data$subreddit, .data$thread_id, .data$comment, 
                   .data$count)
 
-  node_df <- data.frame(user = with(sender_receiver_df, {unique(c(sender, receiver))}), 
+  df_nodes <- data.frame(user = with(df_relations, {unique(c(sender, receiver))}), 
                         stringsAsFactors = FALSE) %>% 
              dplyr::mutate(id = as.integer(dplyr::row_number() - 1)) %>% 
              dplyr::select(.data$id, .data$user)
 
-  edge_df <- sender_receiver_df %>% 
-             dplyr::left_join(node_df %>% 
+  df_edges <- df_relations %>% 
+             dplyr::left_join(df_nodes %>% 
                               dplyr::rename("sender" = .data$user, "from" = .data$id), 
                               by = c("sender" = "sender")) %>% 
-             dplyr::left_join(node_df %>% 
+             dplyr::left_join(df_nodes %>% 
                               dplyr::rename("receiver" = .data$user, "to" = .data$id), 
                               by = c("receiver" = "receiver")) %>%
              dplyr::rename("weight" = .data$count, "title" = .data$comment) %>% 
@@ -109,32 +111,61 @@ Create.actor.reddit <- function(datasource, type, weightEdges = FALSE, textData
   # weight edges network graph
   if (weightEdges) {
     # drop comment id and text
-    edge_df$comment_id <- edge_df$title <- NULL
-    edge_df %<>% dplyr::group_by(.data$from, .data$to) %>% 
+    df_edges$comment_id <- df_edges$title <- NULL
+    df_edges %<>% dplyr::group_by(.data$from, .data$to) %>% 
                  dplyr::summarise(weight = sum(.data$weight)) %>% dplyr::ungroup()  
 
     append_type <- "Weighted"
   # include comment text as edge attribute network graph
   } else if (textData) {
-    edge_df$weight <- NULL
+    df_edges$weight <- NULL
 
     # rename the edge attribute containing the thread comment
-    edge_df %<>% dplyr::rename("vosonTxt_comment" = .data$title)
+    df_edges %<>% dplyr::rename("vosonTxt_comment" = .data$title)
 
-    # problem control characters encountered in reddit text
-    # edge_df$vosonTxt_comment <- gsub("[\x01\x05\x18\x19\x1C]", "", edge_df$vosonTxt_comment, perl = TRUE)
     append_type <- "Txt"
 
-    # remove any characters that are not in punctuation, alphanumeric classes or spaces
     if (cleanText) {
-      edge_df$vosonTxt_comment <- gsub("[^[:punct:]^[:alnum:]^\\s]", "", edge_df$vosonTxt_comment, perl = TRUE)
+      cat("Cleaning comment text.\n")
+      # json encoding issues should be tackled upstream
+      
+      # remove any characters that are not in punctuation, alphanumeric classes or spaces
+      # df_edges$vosonTxt_comment <- gsub("[^[:punct:]^[:alnum:]^\\s^\\n]", "", df_edges$vosonTxt_comment, 
+      #                                   useBytes = TRUE, perl = TRUE)
+      
+      # xml 1.0
+      # allowed #x9 | #xA | #xD | [#x20-#xD7FF] | [#xE000-#xFFFD] | [#x10000-#x10FFFF]
+      # [\x00-\x1F] ^\xE000-\xFFFD^\x10000-\x10FFFF
+      # [^\x09^\x0A^\x0D^\x20-\xD7FF^\xE000-\xFFFD]
+      # [\u0000-\u0008,\u000B,\u000C,\u000E-\u001F]
+      
+      # decode html encoding as not required
+      # df_edges$vosonTxt_comment <- textutils::HTMLdecode(df_edges$vosonTxt_comment)
+      
+      # take care of a couple of known encoding issues
+      df_edges$vosonTxt_comment <- gsub("([\u0019])",
+                                        "'", df_edges$vosonTxt_comment,
+                                        useBytes = TRUE, perl = TRUE)
+      df_edges$vosonTxt_comment <- gsub("([\u0023])",
+                                        "#", df_edges$vosonTxt_comment,
+                                        useBytes = TRUE, perl = TRUE)
+
+      df_edges$vosonTxt_comment <- gsub("([&#x200B;])",
+                                        " ", df_edges$vosonTxt_comment,
+                                        useBytes = TRUE, perl = TRUE)
+      
+      # replace chars outside of allowed xml 1.0 spec
+      df_edges$vosonTxt_comment <- gsub("([\u0001-\u0008\u000B\u000C\u000E-\u001F])",
+                                        "", df_edges$vosonTxt_comment,
+                                        useBytes = TRUE, perl = TRUE)
+      
       append_type <- "CleanTxt"
     }
   } else {
-    edge_df$title <- edge_df$weight <- NULL
+    df_edges$title <- df_edges$weight <- NULL
   }
 
-  g <- graph_from_data_frame(d = edge_df, vertices = node_df, directed = TRUE)
+  g <- graph_from_data_frame(d = df_edges, vertices = df_nodes, directed = TRUE)
 
   # set name to actors user name
   V(g)$name <- V(g)$label <- V(g)$user
